@@ -152,7 +152,7 @@
 #' columns are returned (note: the Kenward-Roger correction does two separate
 #' things: (1) it computes an effective number for the denominator df; (2) it
 #' scales the statistic by a calculated amount, see also
-#' \url{http://stackoverflow.com/a/25612960/289572}):
+#' \url{https://stackoverflow.com/a/25612960/289572}):
 #' \enumerate{
 #'   \item \code{F} computed F statistic
 #'   \item \code{ndf} numerator degrees of freedom (number of parameters used
@@ -334,11 +334,11 @@
 #'   \url{https://github.com/singmann/afex/issues}
 #'   
 #' @author Henrik Singmann with contributions from
-#'   \href{http://stackoverflow.com/q/11335923/289572}{Ben Bolker and Joshua
+#'   \href{https://stackoverflow.com/q/11335923/289572}{Ben Bolker and Joshua
 #'   Wiley}.
 #'   
 #' @seealso \code{\link{aov_ez}} and \code{\link{aov_car}} for convenience
-#'   functions to analyze experimental deisgns with classical ANOVA or ANCOVA
+#'   functions to analyze experimental desIgns with classical ANOVA or ANCOVA
 #'   wrapping \code{\link[car]{Anova}}.
 #'
 #'   see the following for the data sets from Maxwell and Delaney (2004) used
@@ -351,37 +351,37 @@
 #'
 #'   Baayen, R. H., Davidson, D. J., & Bates, D. M. (2008). Mixed-effects
 #'   modeling with crossed random effects for subjects and items. \emph{Journal
-#'   of Memory and Language}, 59(4), 390-412. doi:10.1016/j.jml.2007.12.005
+#'   of Memory and Language}, 59(4), 390-412. \doi{10.1016/j.jml.2007.12.005}
 #'
 #'   Baayen, R. H., & Milin, P. (2010). Analyzing Reaction Times.
 #'   \emph{International Journal of Psychological Research}, 3(2), 12-28.
 #'
 #'   Barr, D. J. (2013). Random effects structure for testing interactions in
 #'   linear mixed-effects models. \emph{Frontiers in Quantitative Psychology and
-#'   Measurement}, 328. doi:10.3389/fpsyg.2013.00328
+#'   Measurement}, 328. \doi{10.3389/fpsyg.2013.00328}
 #'
 #'   Barr, D. J., Levy, R., Scheepers, C., & Tily, H. J. (2013). Random effects
 #'   structure for confirmatory hypothesis testing: Keep it maximal.
 #'   \emph{Journal of Memory and Language}, 68(3), 255-278.
-#'   doi:10.1016/j.jml.2012.11.001
+#'   \doi{10.1016/j.jml.2012.11.001}
 #'
 #'   Bates, D., Kliegl, R., Vasishth, S., & Baayen, H. (2015).
 #'   \emph{Parsimonious Mixed Models}. arXiv:1506.04967 [stat]. Retrieved from
-#'   \url{http://arxiv.org/abs/1506.04967}
+#'   \url{https://arxiv.org/abs/1506.04967}
 #'
 #'   Dalal, D. K., & Zickar, M. J. (2012). Some Common Myths About Centering
 #'   Predictor Variables in Moderated Multiple Regression and Polynomial
 #'   Regression. \emph{Organizational Research Methods}, 15(3), 339-362.
-#'   doi:10.1177/1094428111430540
+#'   \doi{10.1177/1094428111430540}
 #'
 #'   Judd, C. M., Westfall, J., & Kenny, D. A. (2012). Treating stimuli as a
 #'   random factor in social psychology: A new and comprehensive solution to a
 #'   pervasive but largely ignored problem. \emph{Journal of Personality and
-#'   Social Psychology}, 103(1), 54-69. doi:10.1037/a0028347
+#'   Social Psychology}, 103(1), 54-69. \doi{10.1037/a0028347}
 #'
 #'   Luke, S. (2017). Evaluating significance in linear mixed-effects models in
 #'   R. \emph{Behavior Research Methods}.
-#'   \url{https://doi.org/10.3758/s13428-016-0809-y}
+#'   \doi{10.3758/s13428-016-0809-y}
 #'
 #'   Maxwell, S. E., & Delaney, H. D. (2004). \emph{Designing experiments and
 #'   analyzing data: a model-comparisons perspective.} Mahwah, N.J.: Lawrence
@@ -445,31 +445,15 @@ mixed <- function(formula,
   }
   
   ## real function begins:
-  vars.to.check <- all.vars(formula)
-  if (check_contrasts) {
-    #browser()
-    resetted <- NULL
-    for (i in vars.to.check) {
-      if (is.character(data[,i])) {
-        data[,i] <- factor(data[,i])
-      }
-      if (is.factor(data[,i])) {
-        if (is.null(attr(data[,i], "contrasts")) & 
-            (options("contrasts")[[1]][1] != "contr.sum")) {
-          contrasts(data[,i]) <- "contr.sum"
-          resetted  <- c(resetted, i)
-        }
-        else if (!is.null(attr(data[,i], "contrasts")) && 
-                 attr(data[,i], "contrasts") != "contr.sum") {
-          contrasts(data[,i]) <- "contr.sum"
-          resetted  <- c(resetted, i)
-        }
-      }
-    }
-    if (!is.null(resetted)) 
-      message(paste0("Contrasts set to contr.sum for the following variables: ", 
-                    paste0(resetted, collapse=", ")))
-  }
+  vars.to.check <- all.vars(as.formula(formula))
+  data <- check_contrasts(
+    data = data,
+    factors = vars.to.check,
+    check_contrasts = check_contrasts,
+    type = type,
+    warn = FALSE
+  )
+  
   method <- match.arg(method, c("KR", "S", "PB", "LRT", "nested-KR", "F"), 
                       several.ok=FALSE)
   
@@ -494,7 +478,7 @@ mixed <- function(formula,
   mapping <- attr(m.matrix, "assign")
   fixed.vars <- all.vars(rh2)
   # check for missing values in variables used:
-  if (nrow(m.matrix) != nrow(data)) {
+  if (nrow(model.matrix(nobars(formula.f), data = data)) != nrow(data)) {
     data <- model.frame(
       as.formula(paste0(vars.to.check[1], 
                        "~", 
@@ -502,9 +486,10 @@ mixed <- function(formula,
       data = data)
     m.matrix <- model.matrix(rh2, data = data)
     warning(paste0("Due to missing values, reduced number of observations to ", 
-                  nrow(data)))
+                  nrow(data)), call. = FALSE)
     if(set_data_arg) {
-      warning("Due to missing values, set_data_arg set to FALSE.")
+      warning("Due to missing values, set_data_arg set to FALSE.", 
+              call. = FALSE)
       set_data_arg <- FALSE
     }
   }
@@ -550,7 +535,8 @@ mixed <- function(formula,
              method, '"', call. = FALSE)
       mf[[1]] <- quote(lme4::lmer)
     }
-    else stop("value of afex_options('lmer_function') not supported.")
+    else stop("value of afex_options('lmer_function') not supported.", 
+              call. = FALSE)
     use_reml <- TRUE
   }
   mf[["data"]] <- as.name("data")
@@ -568,7 +554,7 @@ mixed <- function(formula,
   }
   if ("family" %in% names(mf)) {
     if (!(method[1] %in% c("LRT", "PB"))) 
-      stop("GLMMs can only be estimated with 'LRT' or 'PB'.")
+      stop("GLMMs can only be estimated with 'LRT' or 'PB'.", call. = FALSE)
   }
   ## do not calculate nested models for these methods:
   if (method[1] %in% c("KR", "S")) {
@@ -899,10 +885,16 @@ mixed <- function(formula,
         }
       }
       names(tests) <- fixed.effects
-      df.large  <- vapply(tests, function(x) x[["Df"]][2], 0)
-      df.small  <- vapply(tests, function(x) x[["Df"]][1], 0)
       chisq  <- vapply(tests, function(x) x[["Chisq"]][2], 0)
-      df  <- vapply(tests, function(x) x[["Chi Df"]][2], 0)
+      if (packageVersion("lme4") <= "1.1.21") {
+        df.large  <- vapply(tests, function(x) x[["Df"]][2], 0)
+        df.small  <- vapply(tests, function(x) x[["Df"]][1], 0)
+        df  <- vapply(tests, function(x) x[["Chi Df"]][2], 0)
+      } else {
+        df.large  <- vapply(tests, function(x) x[["npar"]][2], 0)
+        df.small  <- vapply(tests, function(x) x[["npar"]][1], 0)
+        df  <- vapply(tests, function(x) x[["Df"]][2], 0)
+      }
       p.value  <- vapply(tests, function(x) x[["Pr(>Chisq)"]][2], 0)
       anova_table <- data.frame(Df = df.small, 
                                 Chisq = chisq, 
@@ -912,7 +904,7 @@ mixed <- function(formula,
       rownames(anova_table) <- fixed.effects
       if (type == 3 | type == "III") 
         anova_tab_addition <- paste0("Df full model: ", df.large[1])
-      else anova_tab_addition <- paste0("Df full model(s): ", df.large)
+      else anova_tab_addition <- paste0("Df full model(s): ", paste(df.large, collapse = ", "))
     } else stop('Only methods "KR", "PB", "LRT", or "nested-KR" currently implemented.')
     
   } 
@@ -1066,7 +1058,6 @@ print.mixed <- function(x, ...) {
   invisible(tmp)
 }
 
-
 #anova.mixed <- 
 
 #' @method summary mixed
