@@ -1,11 +1,11 @@
 context("afex_plot: basic functionality")
 
+data(obk.long, package = "afex")
+# estimate mixed ANOVA on the full design:
+a1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), 
+              data = obk.long, observed = "gender")
+
 test_that("all input type works and warnings are correct", {
-  data(obk.long, package = "afex")
-  # estimate mixed ANOVA on the full design:
-  a1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), 
-                data = obk.long, observed = "gender")
-  
   expect_warning(
     em1 <- afex_plot(a1, ~phase*hour, ~treatment+gender, return = "data"),
     "mixed within-between-design"
@@ -54,10 +54,6 @@ test_that("all input type works and warnings are correct", {
 })
 
 test_that("ANOVA plots are produced", {
-  data(obk.long, package = "afex")
-  a1 <- aov_car(value ~ treatment * gender + Error(id/(phase*hour)), 
-                data = obk.long, observed = "gender")
-  
   expect_is(afex_plot(a1, "hour", error = "within"), "ggplot")
   expect_is(afex_plot(a1, c("phase", "hour"), trace = "treatment", 
                       error = "none"), "ggplot")
@@ -184,8 +180,7 @@ test_that("afex_plot works with various geoms (from examples)", {
                   data_geom = ggpol::geom_boxjitter, 
                   data_arg = list(
                     width = 0.3, 
-                    jitter.width = 0,
-                    jitter.height = 10,
+                    jitter.params = list(width = 0, height = 10),
                     outlier.intersect = TRUE),
                   point_arg = list(size = 2.5), 
                   error_arg = list(size = 1.5, width = 0))
@@ -197,8 +192,7 @@ test_that("afex_plot works with various geoms (from examples)", {
                   data_geom = ggpol::geom_boxjitter, 
                   data_arg = list(
                     width = 0.5, 
-                    jitter.width = 0,
-                    jitter.height = 10,
+                    jitter.params = list(width = 0, height = 10),
                     outlier.intersect = TRUE),
                   point_arg = list(size = 2.5), 
                   line_arg = list(linetype = 0),
