@@ -42,7 +42,11 @@ test_that("mixed, obk.long: type 2 and LRTs", {
   a2.h <- lmer(value ~ treatment+phase +(1|id), data = obk.long, REML=FALSE)
   a2.t <- lmer(value ~ treatment +(1|id), data = obk.long, REML=FALSE)
   a2.p <- lmer(value ~ phase +(1|id), data = obk.long, REML=FALSE)
-  extract_anova <- function(anova) unlist(anova)[c("Df1", "Chisq2", "Chi Df2", "Pr(>Chisq)2" )]
+  if (packageVersion("lme4") <= "1.1.21") {
+    extract_anova <- function(anova) unlist(anova)[c("Df1", "Chisq2", "Chi Df2", "Pr(>Chisq)2" )]
+  } else {
+    extract_anova <- function(anova) unlist(anova)[c("npar1", "Chisq2", "Df2", "Pr(>Chisq)2" )]
+  }
   
   expect_that(
     unlist(t2$anova_table[3,])
@@ -240,6 +244,7 @@ test_that("mixed: return=data, expand_re argument, and allFit", {
   #testthat::skip_on_travis()
   testthat::skip_if_not_installed("optimx")
   testthat::skip_on_cran()
+  skip_on_os("windows")
   require(optimx)
   data("ks2013.3")
   ks2013.3_tmp <- ks2013.3
@@ -268,6 +273,7 @@ test_that("mixed with all_fit = TRUE", {
   testthat::skip_if_not_installed("MEMSS")
   testthat::skip_if_not_installed("dfoptim")
   testthat::skip_on_cran()
+  skip_on_os("windows")
   require(optimx)
   data("Machines", package = "MEMSS") 
   aop <- afex_options()
@@ -353,6 +359,7 @@ test_that("mixed with all available methods", {
 test_that("mixed all_fit = TRUE works with old methods", {
   data("sk2011.2") # see example("mixed")
   testthat::skip_on_cran()
+  skip_on_os("windows")
   sk2_aff <- droplevels(sk2011.2[sk2011.2$what == "affirmation",])
   sk2_aff_b <- mixed(response ~ instruction+(inference*type||id), sk2_aff,
                expand_re = TRUE, all_fit = TRUE, method = "nested-KR", 
@@ -371,6 +378,7 @@ test_that("mixed all_fit = TRUE works with old methods", {
 
 
 test_that("mixed all_fit = TRUE works with new (KR) methods", {
+  skip_on_os("windows")
   data("sk2011.2") # see example("mixed")
   testthat::skip_on_cran()
   sk2_aff <- droplevels(sk2011.2[sk2011.2$what == "affirmation",])
